@@ -13,6 +13,7 @@ from ..utils.debug_log import debug_log, info_logger, error_logger, warning_logg
 # New imports for tree-sitter (using tree-sitter-language-pack)
 from tree_sitter import Language, Parser
 from ..utils.tree_sitter_manager import get_tree_sitter_manager
+from ..cli.config_manager import get_config_value
 
 class TreeSitterParser:
     """A generic parser wrapper for a specific language using tree-sitter."""
@@ -524,7 +525,13 @@ class GraphBuilder:
                     MATCH (called) WHERE (called:Function OR called:Class)
                       AND called.name = $called_name 
                       AND called.file_path = $called_file_path
-                    MERGE (caller)-[:CALLS {line_number: $line_number, args: $args, full_call_name: $full_call_name}]->(called)
+                    
+                    WITH caller, called
+                    OPTIONAL MATCH (called)-[:CONTAINS]->(init:Function)
+                    WHERE called:Class AND init.name IN ["__init__", "constructor"]
+                    WITH caller, COALESCE(init, called) as final_target
+                    
+                    MERGE (caller)-[:CALLS {line_number: $line_number, args: $args, full_call_name: $full_call_name}]->(final_target)
                 """,
                 caller_name=caller_name,
                 caller_file_path=caller_file_path,
@@ -540,7 +547,13 @@ class GraphBuilder:
                     MATCH (called) WHERE (called:Function OR called:Class)
                       AND called.name = $called_name 
                       AND called.file_path = $called_file_path
-                    MERGE (caller)-[:CALLS {line_number: $line_number, args: $args, full_call_name: $full_call_name}]->(called)
+                    
+                    WITH caller, called
+                    OPTIONAL MATCH (called)-[:CONTAINS]->(init:Function)
+                    WHERE called:Class AND init.name IN ["__init__", "constructor"]
+                    WITH caller, COALESCE(init, called) as final_target
+
+                    MERGE (caller)-[:CALLS {line_number: $line_number, args: $args, full_call_name: $full_call_name}]->(final_target)
                 """,
                 caller_file_path=caller_file_path,
                 called_name=called_name,
@@ -723,14 +736,21 @@ class GraphBuilder:
                     DETACH DELETE d
                 """, path=path)
 
-    def delete_repository_from_graph(self, repo_path: str):
-        """Deletes a repository and all its contents from the graph."""
+    def delete_repository_from_graph(self, repo_path: str) -> bool:
+        """Deletes a repository and all its contents from the graph. Returns True if deleted, False if not found."""
         repo_path_str = str(Path(repo_path).resolve())
         with self.driver.session() as session:
+            # Check if it exists
+            result = session.run("MATCH (r:Repository {path: $path}) RETURN count(r) as cnt", path=repo_path_str).single()
+            if not result or result["cnt"] == 0:
+                warning_logger(f"Attempted to delete non-existent repository: {repo_path_str}")
+                return False
+
             session.run("""MATCH (r:Repository {path: $path})
                           OPTIONAL MATCH (r)-[:CONTAINS*]->(e)
                           DETACH DELETE r, e""", path=repo_path_str)
             info_logger(f"Deleted repository and its contents from graph: {repo_path_str}")
+            return True
 
     def update_file_in_graph(self, file_path: Path, repo_path: Path, imports_map: dict):
         """Updates a single file's nodes in the graph."""
@@ -786,6 +806,21 @@ class GraphBuilder:
             else:
                 all_files = path.rglob("*")
                 files = [f for f in all_files if f.is_file() and f.suffix in supported_extensions]
+
+                # Filter default ignored directories
+                ignore_dirs_str = get_config_value("IGNORE_DIRS") or ""
+                if ignore_dirs_str:
+                    ignore_dirs = {d.strip().lower() for d in ignore_dirs_str.split(',') if d.strip()}
+                    if ignore_dirs:
+                        kept_files = []
+                        for f in files:
+                            try:
+                                parts = set(p.lower() for p in f.relative_to(path).parent.parts)
+                                if not parts.intersection(ignore_dirs):
+                                    kept_files.append(f)
+                            except ValueError:
+                                kept_files.append(f)
+                        files = kept_files
             
             total_files = len(files)
             estimated_time = total_files * 0.05 # tree-sitter is faster
@@ -836,6 +871,25 @@ class GraphBuilder:
             supported_extensions = self.parsers.keys()
             all_files = path.rglob("*") if path.is_dir() else [path]
             files = [f for f in all_files if f.is_file() and f.suffix in supported_extensions]
+
+            # Filter default ignored directories
+            ignore_dirs_str = get_config_value("IGNORE_DIRS") or ""
+            if ignore_dirs_str and path.is_dir():
+                ignore_dirs = {d.strip().lower() for d in ignore_dirs_str.split(',') if d.strip()}
+                if ignore_dirs:
+                    kept_files = []
+                    for f in files:
+                        try:
+                            # Check if any parent directory in the relative path is in ignore list
+                            parts = set(p.lower() for p in f.relative_to(path).parent.parts)
+                            if not parts.intersection(ignore_dirs):
+                                kept_files.append(f)
+                            else:
+                                # debug_log(f"Skipping default ignored file: {f}")
+                                pass
+                        except ValueError:
+                             kept_files.append(f)
+                    files = kept_files
             
             if spec:
                 filtered_files = []
